@@ -7,14 +7,17 @@ import numpy as np
 from sklearn.model_selection import train_test_split
 from sklearn.preprocessing import OneHotEncoder
 
-from .utils import *
+try:
+    from .utils import *
+except:
+    from utils import *
 
 
 def get_dataset_numpy(path, onehot_labels=True, reduce_dimensionality=False, reduce_method='PCA', n_dimensions=60,
                       subsample_data=True, subsample_freq=2, train_size=0.7, random_state=42, normal_samples=1,
                       damaged_samples=1, assembly_samples=1, missing_samples=1, damaged_thread_samples=0,
                       loosening_samples=1, move_samples=1, drop_extra_columns=True, pad_data=True,
-                      label_type='partial', binary_labels=False, standardize=False):
+                      label_type='partial', binary_labels=False, standardize=False, screwdriver_only = False):
     """
     Create numpy dataset from input h5 file
 
@@ -59,6 +62,8 @@ def get_dataset_numpy(path, onehot_labels=True, reduce_dimensionality=False, red
         if True apply z-score standardisation
     :param pad_data: bool,
         if True pad data to equal length samples, if False return data in continuous form
+    :param screwdriver_only: bool,
+        take only the 4 dimensions from the screwdriver sensors
 
     :return: 4 np arrays,
         train and test data & labels
@@ -67,6 +72,9 @@ def get_dataset_numpy(path, onehot_labels=True, reduce_dimensionality=False, red
 
     print('Loaded data')
 
+    if screwdriver_only:
+        data = screwdriver_data(data)
+
     if subsample_data:
         data = subsample(data, subsample_freq)
 
@@ -74,7 +82,7 @@ def get_dataset_numpy(path, onehot_labels=True, reduce_dimensionality=False, red
         print('Relabeling data')
         data = relabel_tighten(data)
 
-    if drop_extra_columns:
+    if drop_extra_columns and not screwdriver_only:
         data = drop_columns(data)
 
     if normal_samples < 1 or damaged_samples < 1 or assembly_samples < 1 or missing_samples < 1 or \
@@ -123,7 +131,8 @@ def get_dataset_generator(path, window_size=100, reduce_dimensionality=False, re
                           subsample_data=True, subsample_freq=2, train_size=0.7, random_state=42, normal_samples=1,
                           damaged_samples=1, assembly_samples=1, missing_samples=1, damaged_thread_samples=0,
                           loosening_samples=1, drop_loosen=True, drop_movement=False, drop_extra_columns=True,
-                          label_type='partial', batch_size=256, binary_labels=False, standardize=False):
+                          label_type='partial', batch_size=256, binary_labels=False, standardize=False,
+                          screwdriver_only=False):
     """
     Create Keras sliding window generator from input h5 file
 
@@ -170,6 +179,8 @@ def get_dataset_generator(path, window_size=100, reduce_dimensionality=False, re
         if True all anomalies are labeled the same
     :param standardize: bool,
         if True apply z-score standardisation
+    :param screwdriver_only: bool,
+        take only the 4 dimensions from the screwdriver sensors
 
     :return: 4 np arrays,
         train and test data & labels
@@ -180,17 +191,18 @@ def get_dataset_generator(path, window_size=100, reduce_dimensionality=False, re
 
     print('Loaded data')
 
+    if screwdriver_only:
+        data = screwdriver_data(data)
+
     if subsample_data:
         data = subsample(data, subsample_freq)
 
     if label_type == 'partial':
-        drop_loosen = False
         data = relabel_partial(data)
     elif label_type == 'tighten':
-        drop_loosen = False
         data = relabel_tighten(data)
 
-    if drop_extra_columns or drop_loosen or drop_movement:
+    if drop_extra_columns and not screwdriver_only:
         data = drop_columns(data)
 
     if binary_labels:
